#!/bin/bash
COM_ERR=1
INSTALL_DIR=/opt/solar
CONF_FILE=solar_pi.conf
LIB=solar_pi.lib


source $INSTALL_DIR/$CONF_FILE




if [ $# -eq 0 ]
then
	echo "Please type \"solar_pi.sh -help\" for a list of commands"
	exit 0
fi


if [ $1 = "-help" ]
then
	COM_ERR=0
	
	echo "List of commands"
	echo ""
	
	echo "-board_info"
	echo "-status"
	echo "-battery_v"
	echo "-solar_v"
	echo "-current_5v"
	echo "-current_solar"
	echo "-temp"
	echo "-charger_<on/off>"
	echo "-io_read_inputs"
	echo "-io_out <io_num> <val>"
	echo "-io_read_direction"
	echo "-io_set_direction <io_num> <dir>"
	echo "-fan_speed <0/50/75/100>"
	echo "-sleep <sec>"
	echo "-read_wake_up_sources"
	echo "-set_wake_up_sources <solar_v> <bat_v> <rtc_sec>"
	echo "-power_cycle <sec>"
	echo "-rtc_status"
	echo "-rtc_set_time_from_pi"
	echo "-rtc_copy_time_to_pi"
	echo "-i2c_find"
	echo "-i2c_change_addr <new_addr>"
	echo "-fw_update <file_name>"
	

#Read Board information
elif [ $1 = "-board_info" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -board_info
	exit $?


#Read battery voltage
elif [ $1 = "-battery_v" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -battery_v
	exit $?


#Read Solar Panel Voltage
elif [ $1 = "-solar_v" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -solar_v
	exit $?

#Read 5V current
elif [ $1 = "-current_5v" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -current_5v
	exit $?

#Read Solar Panel current
elif [ $1 = "-current_solar" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -current_solar
	exit $?
	
	
#Read Board Temperature
elif [ $1 = "-temp" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -temp
	exit $?


#Turn off 5V in 0-255 seconds, then go to sleep
elif [ $1 = "-sleep" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -sleep $2
		exit $?
	else
		echo "ERROR: Expecting an argument for seconds delay"
	fi




#Tells the solar pi to wait (0-255) seconds, then power cycle 5V
elif [ $1 = "-power_cycle" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -power_cycle $2
		exit $?
	else
		echo "ERROR: Expecting an argument for seconds delay"
	fi



#Read Wake Up sources, when device is is sleep mode one of these things sources
#can wake it up
elif [ $1 = "-read_wake_up_sources" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -read_wake_up_sources
	exit $?


#Setup the wake up sources that can wake the system up from sleep
#-set_wake_up <arg1> <arg2> <arg3>
#arg1 = solar panel wake up voltage
#arg2 =  battery wake up voltage
#arg3 = real time clock alarm in seconds from now
#Decimal points are allowed, to disable enter 0
#For example to configure the solar panel voltage wake to be 19.8V, real time clock to interrup 1 hour from now,
#and disable the battery voltage wake up, the call would be "solar_pi.sh -set_wake_up_sources 13.1 0 3600"
elif [ $1 = "-set_wake_up_sources" ]
then
	if [ $# -eq 4 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -set_wake_up_sources $2 $3 $4
		exit $?
	else
		echo "ERROR: Expecting three arguments, solar_v bat_v rtc_sec"
	fi



#Enable battery charger
elif [ $1 = "-charger_on" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -charger_on $FULL_BATTERY_V $MAX_BAT_CHARGE_CURRENT
	exit $?



#Disable battery charger
elif [ $1 = "-charger_off" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -charger_off
	exit $?



#Read RTC status
elif [ $1 = "-rtc_status" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -rtc_status
	exit $?


#Read system time and write it to the real time clock
elif [ $1 = "-rtc_set_time_from_pi" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -rtc_set_time_from_pi
	exit $?


#Read real time clock time and set system time based on that
elif [ $1 = "-rtc_copy_time_to_pi" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -rtc_copy_time_to_pi
	exit $?



#Read status
elif [ $1 = "-status" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -status
	exit $?



#Read IO inputs
elif [ $1 = "-io_read_inputs" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -io_read_inputs
	exit $?


#Setup IO_x pins as inputs/outputs, first argument is the IO pin 1
#and the second argument is 1 or 0, 1 makes the pin an input and 0 makes it an output
elif [ $1 = "-io_set_direction" ]
then
	if [ $# -eq 3 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -io_set_direction $2 $3
		exit $?
	else
		echo "ERROR: Expecting two arguments, IO_NUM and direction, for example -io_set_direction 1 0"
	fi


#Read IO pin direction setting
elif [ $1 = "-io_read_direction" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -io_read_direction
	exit $?


#Drives the outputs
#First argument is the IO pin number from 1 to 5 and the second argument is 1 or 0
#1 drives high and 0 drives low
elif [ $1 = "-io_out" ]
then
	if [ $# -eq 3 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -io_out $2 $3
		exit $?
	else
		echo "ERROR: Expecting two arguments, IO_NUM and value, for example -io_out 1 0"
	fi


#Fan speed, argument should be {0,50,75,100}
elif [ $1 = "-fan_speed" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -fan_speed $2
		exit $?
	else
		echo "ERROR: Expecting an argument, {0,50,75,100}"
	fi



#Scans the i2c bus to find the device
#Note: I2C address inside .conf file will be updated automatically 
elif [ $1 = "-i2c_find" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -i2c_find
	
	tmp="$(printf '%x\n' $?)"
	
	if [ $tmp != ff ]
	then
		#Update .conf file
		echo "Updating I2C_ADDR variable inside $INSTALL_DIR/$CONF_FILE to $tmp"
		sudo sed -i "/I2C_ADDR=/c\I2C_ADDR=$tmp" $INSTALL_DIR/$CONF_FILE
	else
		echo $?
	fi


#Change I2C address
#Note: I2C address inside .conf file will be updated automatically 
elif [ $1 = "-i2c_change_addr" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -i2c_change_addr $2
		
		if [ $? -eq 0 ]
		then
			#Update .conf file
			echo "Updating I2C_ADDR variable inside $CONF_FILE to $2"
			sudo sed -i "/I2C_ADDR=/c\I2C_ADDR=$2" $INSTALL_DIR/$CONF_FILE
		else
			echo "ERROR: Failed to update I2C address."
		fi
		
		exit $?
	else
		echo "ERROR: Expecting a hex number as an argument"
	fi


#Firmware update
elif [ $1 = "-fw_update" ]
then
	
	if [ $# -ne 2 ]
	then
		echo "Missing file name argument"
	elif [ -f $2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -fw_update $2
	else
		echo "File doesn't exist"	
	fi
	
	exit $?


#Firmware update recovery
elif [ $1 = "-fw_update_recover" ]
then
	
	if [ $# -ne 2 ]
	then
		echo "Missing file name argument"
	elif [ -f $2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -fw_update_recover $2
	else
		echo "File doesn't exist"	
	fi
	
	exit $?

else
	echo "Unknown command($1), please use -help to see valid commands"
fi



if [ $COM_ERR = "1" ]
then
	echo "Error"
fi
	
	